diff --git a/tools/profiling/qps/qps_diff.py b/tools/profiling/qps/qps_diff.py
index 65c845caa1f18789f3ff80965adac254e9f2e74b..0654f45666fe2f5ee71a97ca5bf5d96230cb1191 100755
--- a/tools/profiling/qps/qps_diff.py
+++ b/tools/profiling/qps/qps_diff.py
@@ -118,7 +118,7 @@ def diff(scenarios, loops, old, new):
   for sn in scenarios:
     old_data[sn] = []
     new_data[sn] = []
-    for i in range(0, loops):
+    for i in range(loops):
       old_data[sn].append(_load_qps("%s.%s.%d.json" % (sn, old, i)))
       new_data[sn].append(_load_qps("%s.%s.%d.json" % (sn, new, i)))
 
diff --git a/tools/profiling/qps/qps_scenarios.py b/tools/profiling/qps/qps_scenarios.py
index d473d7cd24019b11ea1066b36b1ef60562b7388c..4fbbdefc4db54e6e8c4c2771a05c34d70d33a7a5 100644
--- a/tools/profiling/qps/qps_scenarios.py
+++ b/tools/profiling/qps/qps_scenarios.py
@@ -1,5 +1,3 @@
-#!/usr/bin/env python2.7
-#
 # Copyright 2017 gRPC authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
diff --git a/tools/jenkins/run_performance.sh b/tools/jenkins/run_performance.sh
index 9529b0126fc64bedf361d994c4de9a2e460801a9..3ce05cc7f1e8fda214a285d97a551d6fada94447 100755
--- a/tools/jenkins/run_performance.sh
+++ b/tools/jenkins/run_performance.sh
@@ -13,11 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
 # This script is invoked by Jenkins and runs a diff on the qps drivers
 set -ex
 
+# List of benchmarks that provide good signal for analyzing performance changes in pull requests
+BENCHMARKS_TO_RUN="bm_fullstack_unary_ping_pong bm_fullstack_streaming_ping_pong bm_fullstack_streaming_pump bm_closure bm_cq bm_call_create bm_error bm_chttp2_hpack bm_chttp2_transport bm_pollset bm_metadata"
+
 # Enter the gRPC repo root
 cd $(dirname $0)/../..
 
 tools/run_tests/start_port_server.py
-tools/profiling/qps/qps_diff.py -d origin/$ghprbTargetBranch 
+tools/profiling/microbenchmarks/bm_diff/bm_main.py -d origin/$ghprbTargetBranch -b $BENCHMARKS_TO_RUN
@@ -13,11 +13,14 @@
 # limitations under the License.
 #
-# This script is invoked by Jenkins and runs a diff on the qps drivers
+# This script is invoked by Jenkins and runs a diff on the microbenchmarks
 set -ex
 
diff --git a/tools/jenkins/run_performance_old.sh b/tools/jenkins/run_qps_diff.sh
similarity index 58%
rename from tools/jenkins/run_performance_old.sh
rename to tools/jenkins/run_qps_diff.sh
index 3ce05cc7f1e8fda214a285d97a551d6fada94447..9529b0126fc64bedf361d994c4de9a2e460801a9 100755
--- a/tools/jenkins/run_performance_old.sh
+++ b/tools/jenkins/run_qps_diff.sh
@@ -13,14 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
 # This script is invoked by Jenkins and runs a diff on the microbenchmarks
 set -ex
 
-# List of benchmarks that provide good signal for analyzing performance changes in pull requests
-BENCHMARKS_TO_RUN="bm_fullstack_unary_ping_pong bm_fullstack_streaming_ping_pong bm_fullstack_streaming_pump bm_closure bm_cq bm_call_create bm_error bm_chttp2_hpack bm_chttp2_transport bm_pollset bm_metadata"
-
 # Enter the gRPC repo root
 cd $(dirname $0)/../..
 
 tools/run_tests/start_port_server.py
-tools/profiling/microbenchmarks/bm_diff/bm_main.py -d origin/$ghprbTargetBranch -b $BENCHMARKS_TO_RUN
+tools/profiling/qps/qps_diff.py -d origin/$ghprbTargetBranch 
@@ -13,14 +13,11 @@
 # limitations under the License.
 #
-# This script is invoked by Jenkins and runs a diff on the microbenchmarks
+# This script is invoked by Jenkins and runs a diff on the qps drivers
 set -ex
 